import * as React from 'react';
import { Table, Button, Modal, Input, Header, Container, InputOnChangeData, ButtonProps } from 'semantic-ui-react';
import { TargetDetails } from './TargetDetail';

import Target from '@overflow/target/api/model/Target';
import Probe from '@overflow/probe/api/model/Probe';

export interface StateProps {

}

export interface DispatchProps {
  onReadAllByProbe(probe: Probe): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: Target;
  openAddTarget: boolean;
}

export class TargetList extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      selected: null,
      openAddTarget: false,
    };
  }

  public handleAddTarget(event: React.MouseEvent<HTMLButtonElement>, data: ButtonProps): void {
    this.setState({
      openAddTarget: true,
    });
  }

  public render(): JSX.Element {

    return (
      <Container fluid>
        {/*search bar  */}
        <TargetTable />
        <br />
        <Button content='Add' icon='add' labelPosition='left' floated='right' positive onClick={this.handleAddTarget.bind(this)} />
        <br /><br /><br /><br /><br /><br /><br /><br /><br />
        <TargetDetails target={this.state.selected} />

        <Modal
          open={this.state.openAddTarget}
        >
          <Modal.Header>
            Adding a Target
          </Modal.Header>
          <Modal.Content>
            <p>contents</p>
          </Modal.Content>
          <Modal.Actions>
            <Button negative onClick={() => this.setState({ openAddTarget: false })}>Cancel</Button>
            <Button positive labelPosition='right' icon='checkmark' content='Done' />
          </Modal.Actions>
        </Modal>
      </Container>
    );
  }
}

export interface TargetTableProps {

}

export interface TargetTableState {
  list: Array<Target>;
  selected: Target;
}

export class TargetTable extends React.Component<TargetTableProps, TargetTableState> {
  private data: any;

  constructor(props: TargetTableProps, context: TargetTableState) {
    super(props, context);
    this.state = {
      selected: null,
      list: [],
    };
  }
  public handleSelect(selectedTarget: Target): void {
    this.setState({
      selected: selectedTarget,
    });
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        <Table celled selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>No.</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Type</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Name</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Version</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.state.list.map((target: Target, index: number) => (
              <Table.Row key={index} onClick={this.handleSelect.bind(this, target)}>
                <Table.Cell textAlign={'center'}>{index + 1}</Table.Cell>
                <Table.Cell textAlign={'center'}>todo</Table.Cell>
                <Table.Cell>todo</Table.Cell>
                <Table.Cell>todo</Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
      </Container>
    );
  }

}



